(OCR-GLS-G6) OCR
================

|github release version| |python version| |license|

--------------

วิธีติดตั้ง
===========

เปิด CMD / Terminal

.. code:: python

   pip install OCR-GLS-G6

--------------

พัฒนาโดย: GLS Develop G6

.. |github release version| image:: https://img.shields.io/pypi/pyversions/OCR-GLS-G6
.. |python version| image:: https://img.shields.io/pypi/v/OCR-GLS-G6
   :target: https://pypi.org/project/OCR-GLS-G6/0.0.6/
.. |license| image:: https://img.shields.io/github/license/nhn/tui.editor.svg
